weaviate
========

.. automodule:: weaviate
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
===========

.. toctree::
   :maxdepth: 2

   weaviate.auth
   weaviate.batch
   weaviate.backup
   weaviate.classification
   weaviate.client
   weaviate.cluster
   weaviate.connect
   weaviate.contextionary
   weaviate.data
   weaviate.exceptions
   weaviate.gql
   weaviate.schema
   weaviate.wcs
   weaviate.util
